==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Créer un plan d'image...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Créer une image plane dans l'espace 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Créer une image plane dans l'espace 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Ouvrir...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Ouvrir une image</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Type d'espace colorimétrique indéfini</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Format de l'image en pixels</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Sélectionner l'orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Plan de l'image</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Plan XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>Plan XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>Plan YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Inverser la direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Décalage :</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Adapter l'image</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Étirer l'image pour l'adapter à la vue</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Échelle &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Afficher l'image à l'échelle 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>Couleurs d'&amp;origine</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Afficher l'image avec ses couleurs d'origine</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>Couleurs é&amp;claircies</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Afficher l'image avec des couleurs éclaircies</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Prêt...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>gris</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>image extérieure</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Visionneuse d'image</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Images (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Choisir un fichier d'image à ouvrir</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Tous les fichiers</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Erreur à l'ouverture de l'image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Impossible de charger l'image choisie</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Erreur à l'ouverture de l'image</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Impossible de charger l'image choisie</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Créer un plan d'image...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Créer une image plane dans l'espace 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Créer une image plane dans l'espace 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Ouvrir...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Ouvrir une image</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Échelle ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Redimensionnement d'image</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Type d'espace colorimétrique indéfini</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Format de l'image en pixels</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Sélectionner l'orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Plan de l'image</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Plan XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>Plan XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>Plan YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Inverser la direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Décalage :</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Adapter l'image</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Étirer l'image pour l'adapter à la vue</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Échelle &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Afficher l'image à l'échelle 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>Couleurs d'&amp;origine</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Afficher l'image avec ses couleurs d'origine</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>Couleurs é&amp;claircies</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Afficher l'image avec des couleurs éclaircies</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Prêt...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>gris</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>image extérieure</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Visionneuse d'image</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Images (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Choisir un fichier d'image à ouvrir</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Tous les fichiers</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Erreur à l'ouverture de l'image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Impossible de charger l'image choisie</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Erreur à l'ouverture de l'image</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Impossible de charger l'image choisie</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Image</translation>
    </message>
  </context>
</TS>
